@@ -88,7 +88,7 @@ class hmath_setting:
         HDD_save_time = 60
         def HDD_save_reset():
             memo_plk = open("%smemo.plk" %directory, "w", encoding='UTF-8')
-            memo_plk.write(str(dumps({"B":{},"ln":{},"rad":{},"exp":{},"sin":{},"cos":{},"tan":{},"csc":{},"sec":{},"cot":{},"log":{},"log2":{},"zeta":{},"asin":{},"acos":{},"atan":{},"acsc":{},"asec":{},"acot":{},"sinh":{},"cosh":{},"tanh":{},"csch":{},"sech":{},"coth":{},"cube":{},"sqrt":{},"log10":{},"asinh":{},"acosh":{},"atanh":{},"acsch":{},"asech":{},"acoth":{},"Gamma":{},"diganma":{},"radical":{},"factorial":{},"reduct_fract":{},"prime_test":{},"prime_factorization":{}})))
+            memo_plk.write(str(dumps({"B":{},"ln":{},"rad":{},"exp":{},"sin":{},"cos":{},"tan":{},"csc":{},"sec":{},"cot":{},"log":{},"log2":{},"zeta":{},"asin":{},"acos":{},"atan":{},"acsc":{},"asec":{},"acot":{},"sinh":{},"cosh":{},"tanh":{},"csch":{},"sech":{},"coth":{},"cube":{},"sqrt":{},"log10":{},"asinh":{},"acosh":{},"atanh":{},"acsch":{},"asech":{},"acoth":{},"Gamma":{},"diganma":{},"radical":{},"factorial":{},"reduct_fract":{},"prime_test":{},"prime_fact":{}})))
             memo_plk.close()
     class fract:
         max_about_minute_limit : int = 40
@@ -610,33 +610,33 @@ class fract:
     #+
     def __add__(self, other):
         if not type(other) == fract:
-            return fract(self.mole + other * self.deno, self.deno)
+            return fract(self.mole + other * self.deno, self.deno, self.reduct_fract_count + 2)
         return fract(self.mole * other.deno + other.mole * self.deno, self.deno * other.deno, max(self.reduct_fract_count, other.reduct_fract_count) + 2)
     def __radd__(self, other):
-        return fract(self.mole + other * self.deno, self.deno)
+        return fract(self.mole + other * self.deno, self.deno, self.reduct_fract_count + 2)
     #-
     def __sub__(self, other):
         if not type(other) == fract:
-            return fract(self.mole - other * self.deno, self.deno)
+            return fract(self.mole - other * self.deno, self.deno, self.reduct_fract_count + 2)
         return fract(self.mole * other.deno - other.mole * self.deno, self.deno * other.deno, max(self.reduct_fract_count, other.reduct_fract_count) + 2)
     def __rsub__(self, other):
-        return fract(self.mole - other * self.deno, self.deno)
+        return fract(self.mole - other * self.deno, self.deno, self.reduct_fract_count + 2)
     def __neg__(self):
         return fract(-self.mole, self.deno)
     #*
     def __mul__(self, other):
         if not type(other) == fract:
-            return fract(self.mole * other, self.deno)
+            return fract(self.mole * other, self.deno, self.reduct_fract_count + 2)
         return fract(self.mole * other.mole, self.deno * other.deno, max(self.reduct_fract_count, other.reduct_fract_count) + 1)
     def __rmul__(self, other):
-        return fract(self.mole * other, self.deno)
+        return fract(self.mole * other, self.deno, self.reduct_fract_count + 2)
     #/
     def __truediv__ (self, other):
         if not type(other) == fract:
-            return fract(self.mole, self.deno * other)
+            return fract(self.mole, self.deno * other, self.reduct_fract_count + 2)
         return fract(self.mole * other.deno, self.deno * other.mole, max(self.reduct_fract_count, other.reduct_fract_count) + 1)
     def __rtruediv__(self, other):
-        return fract(self.deno * other, self.mole)
+        return fract(self.deno * other, self.mole, self.reduct_fract_count + 2)
     
     def __floordiv__ (self, other):
         value_1 = self / other
@@ -647,10 +647,10 @@ class fract:
     #**
     def __pow__ (self, other):
         if not type(other) == fract:
-            return fract(self.mole ** other, self.deno ** other)
+            return fract(self.mole ** other, self.deno ** other, self.reduct_fract_count + 2)
         return fract(self.mole ** (other.mole / other.deno), self.deno ** (other.mole / other.deno), self.reduct_fract_count)
     def __rpow__(self, other):
-        return other ** (self.mole / self.deno)
+        return other ** (self.mole / self.deno, self.reduct_fract_count + 2)
     
     def __divmod__ (self, other):
         value_1 = self // other
@@ -779,26 +779,39 @@ def prime_test(_n) -> bool | array | list:
 
 @__list
 @__memo
-def prime_factorization(_n : int) -> array | list:
+def prime_fact(_n : int) -> array | list:
     """
-    "prime_factorization(x)" returns the result of factoring x into prime factors.
+    "prime_fact(x)" returns the result of factoring x into prime factors.
     """
     if prime_test(_n):
-        return _n
-    decomposition_result = []
-    prime_factorization2_ans_1 = _n
-    prime_factorization2_ans_2 = 1
-    while not(prime_factorization2_ans_1 == 1):
-        prime_factorization2_ans_2 = prime_factorization2_ans_1
-        for k in range(2 , int(prime_factorization2_ans_1 ** 0.5) + 1):
-            if prime_factorization2_ans_1 / k == prime_factorization2_ans_1 // k / 1:
-                if prime_test(k):
-                    prime_factorization2_ans_2 = k
-                    break
-        prime_factorization2_ans_1 = prime_factorization2_ans_1 / prime_factorization2_ans_2
-        if not(prime_factorization2_ans_2 == 1):
-            decomposition_result += [int(prime_factorization2_ans_2)]
-    return decomposition_result
+        return [_n]
+    n = _n
+    ans = []
+    while n != 1:
+        prime_plase = 0
+        prime_number = 2
+        while n % prime_number != 0:
+            prime_number = prime(prime_plase)
+            prime_plase += 1
+        ans += [prime_number]
+        n = n / prime_number
+    return ans
+
+prime_list : list = [2, 3, 5, 7]
+@__list
+def prime(_n : int):
+    global prime_list
+    try:
+        return prime_list[_n + 1]
+    except:
+        try:
+            k = prime_list[_n] + 2
+        except:
+            k = prime(_n - 1) + 2
+        while not prime_test(k):
+            k += 2
+        prime_list += [k]
+        return k
 
 @__list
 @__memo
@@ -831,8 +844,8 @@ def B(_n : int) -> fract | array | list:
 @__list
 @__memo
 def rad(_n : int) -> int:
-    factorization = prime_factorization(_n)
-    if type(factorial) != list:
+    factorization = prime_fact(_n)
+    if type(factorization) != list:
         return _n
     existing_value = []
     ans = 1
@@ -1258,4 +1271,6 @@ try:
     __corresponding_dictionary = load(memo_plk)
     memo_plk.close()
 except:
-    __corresponding_dictionary = {"B":{},"ln":{},"rad":{},"exp":{},"sin":{},"cos":{},"tan":{},"csc":{},"sec":{},"cot":{},"log":{},"log2":{},"zeta":{},"asin":{},"acos":{},"atan":{},"acsc":{},"asec":{},"acot":{},"sinh":{},"cosh":{},"tanh":{},"csch":{},"sech":{},"coth":{},"cube":{},"sqrt":{},"log10":{},"asinh":{},"acosh":{},"atanh":{},"acsch":{},"asech":{},"acoth":{},"Gamma":{},"diganma":{},"radical":{},"factorial":{},"reduct_fract":{},"prime_test":{},"prime_factorization":{}}
\ No newline at end of file
+    __corresponding_dictionary = {"B":{},"ln":{},"rad":{},"exp":{},"sin":{},"cos":{},"tan":{},"csc":{},"sec":{},"cot":{},"log":{},"log2":{},"zeta":{},"asin":{},"acos":{},"atan":{},"acsc":{},"asec":{},"acot":{},"sinh":{},"cosh":{},"tanh":{},"csch":{},"sech":{},"coth":{},"cube":{},"sqrt":{},"log10":{},"asinh":{},"acosh":{},"atanh":{},"acsch":{},"asech":{},"acoth":{},"Gamma":{},"diganma":{},"radical":{},"factorial":{},"reduct_fract":{},"prime_test":{},"prime_fact":{}}
+
+directory = f"P:\python\hmath\packaging_tutorial\hmath\hmath"
\ No newline at end of file
